<?php
namespace Teknisa\CRM\Service;

use Teknisa\CRM\Factory\ParceiroNegocioFactory;

class crmClienteService {
    
    protected $newCode;
    protected $clienteFactory;
    protected $leadFactory;
    protected $parceiroFactory;
    
    public function __construct ($clienteFactory, $newCode, $environment, $leadFactory, ParceiroNegocioFactory $parceiroFactory){
        
        $this->clienteFactory = $clienteFactory;
        $this->parceiroFactory  = $parceiroFactory;
        $this->leadFactory    = $leadFactory;
        $this->newCode        = $newCode;
        $this->environment    = $environment;
    }
    
    public function prepareInsertProspectEvolutionNextTask($row){

        $row["NRSEQFILACONTA"] = $this->newCode->getCodeByTableName("FILACONTATO", $row["NRORG"]);
        $paramsInsertProspectEvolNextTask = array(
            "DSFILACONTATO"         => $row["DSFILACONTATO"],
            "DTPLANFILACONTA"       => $row["DTPLANFILACONTA"],
            "CDOPERREAL"            => $row["CDOPERREAL"],
            "NRSEQFILACONTA"        => $row["NRSEQFILACONTA"],
            "NRORG"                 => $row["NRORG"],
            "CRM_NRORGTRAB"         => empty($row["CRM_NRORGTRAB"]) ? $row["NRORG"] : $row["CRM_NRORGTRAB"],
            "NRORGINCLUSAO"         => $row["NRORG"],
            "CDOPERINCLUSAO"        => $row["CDOPEREVOL"],
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
            "NRCONTATO"             => $row["NRSEQCONTATO"],
            "NRPRIORFILACONT"       => $row["NRPRIORFILACONT"],
            "NRSEQCONTATO"          => $row["NRSEQCONTATO"],
            "NRSEQCLASSIFICATAREFA" => empty($row['NRSEQCLASSIFICATAREFA']) ? '' : $row['NRSEQCLASSIFICATAREFA'],
            "NRSEQINTERLOCUTOR"         => empty($row['NRSEQINTERLOCUTOR']) ? '' : $row['NRSEQINTERLOCUTOR'],
            "DSEMAILTAREFA"             => empty($row['EMAILINTERLOC']) ? '' : $row['EMAILINTERLOC'],
            "DSTELEFONETAREFA"          => empty($row['NRTELEFONE1']) ? '' : $row['NRTELEFONE1'],
        );
        
        $this->clienteFactory->insertProspectEvolNextTask($paramsInsertProspectEvolNextTask);
        return $row["NRSEQFILACONTA"];
        
    }
    
    public function verificaTarefas($row){
        
        $paramsVerificaTarefas = array(
            
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
            "NRORG"                 => $row["NRORG"]
            
        );
        
        $retorno = $this->clienteFactory->verificaTarefas($paramsVerificaTarefas);
        if(count($retorno) > 0){
            return $retorno;
        }
        
        return false;
    }
    
    public function getOperador($cdoperador, $nrorg){
        
        $paramsSelectOperador = array(
            "CDOPERREAL"            => $cdoperador,
            "NRORG"                 => $nrorg
        );
        
        $retorno = $this->clienteFactory->getOperador($paramsSelectOperador);
        
        if(!empty($retorno)){
            return $retorno[0]['NMOPERADOR'];
        }else{
            return false;
        }
        
        
    }
    
     public function getParceiro($parcnegocio, $nrorg){
        
        $paramsSelectParceiro = array(
            "NRPARCNEGOCIO"           => $parcnegocio,
            "NRORG"                 => $nrorg
        );
        
        $retorno = $this->clienteFactory->getParceiro($paramsSelectParceiro);
        
        if(!empty($retorno)){
            return $retorno[0]['NMPRINCIPALPARC'];
        }else{
            return false;
        }
    }
    
    public function prepareSelectProspectContact($row){
        $paramsSelectProspectContact = array(
            
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
            "NRORG"                 => $row["NRORG"]
            
        );
        
        $retorno = $this->clienteFactory->selectProspectContact($paramsSelectProspectContact);
        if(count($retorno) > 0){
            return $retorno[0];
        }
        
        return array();
    }
    
    public function callForInsertNrseqcontatoForNewOpportunity($row){
        
        $paramsUpdateOpportunity = array(
        
            "NRSEQOPORT"            => $row["NRSEQOPORT"],
            "NRSEQCONTATO"          => $row["NRSEQCONTATO"]
        
        );
        
        $this->clienteFactory->requestForInsertNrseqcontatoForNewOpportunity($paramsUpdateOpportunity);
        
    }
    
    public function callForUpdatePartnerType($row){
        
        $paramsUpdatePartnerType = array(
        
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"]
            
        );
        
        $this->clienteFactory->requestForUpdatePartnerType($paramsUpdatePartnerType);
        
    }
    
    public function callForInsertPartnershipOfTypeClient($row){
        
        $row["NRPARCERIA"] = $this->newCode->getCodeByTableName("PARCERIA", $row["NRORG"]);
        
        $paramsInsertPartnership = array(
            
            "NRPARCERIA"            => $row["NRPARCERIA"],
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
            "NRORG"                 => $row["NRORG"],
            "NRORGINCLUSAO"         => $row["NRORG"],
            "CDOPERINCLUSAO"        => $row["CDOPERADOR"]
            
        );
        
        $this->clienteFactory->requestForInsertPartnershipOfTypeClient($paramsInsertPartnership);
        
    }
    
    public function callForInsertClient($row){
        
        if(!isset($row["NRFUNCPROS"])){
            
            $row["NRFUNCPROS"] = $row["NMRAZSOCCLIE"];
            
        }
        
        $paramsInsertClient = array(
            
            "CDCLIENTE"             => $row["CDCLIENTE"],
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
            "IDTPIJURCLIE"          => $row["IDTPIJURPROS"],
            "NRINSJURCLIE"          => $row["NRINSJURCLIE"],
            "NMRAZSOCCLIE"          => $row["NMRAZSOCCLIE"],
            "NMFANTCLIE"            => $row["NRFUNCPROS"],
            "NRORG"                 => $row["NRORG"],
            "NRORGINCLUSAO"         => $row["NRORGINCLUSAO"],
            "CDOPERINCLUSAO"        => $row["CDOPERINCLUSAO"],
            "IDPRIPUBCLIE"          => $row["IDPRIPUBCLIE"]
            
        );
        
        $this->clienteFactory->requestForInsertClient($paramsInsertClient);
        
    }
    
    public function callForDeactivateProspect($row){
        
        $paramsUpdateProspect = array(
            
            "CDPROSPECT"            => $row["CDPROSPECT"]
        
        );
        
        $this->clienteFactory->requestForDeactivateProspect($paramsUpdateProspect);
    }
    
    public function callForInsertClientAddress($row){
        
        $paramsInsertClientAddress = array(
            
            "CDCLIENTE"             => $row["CDCLIENTE"],
            "CDPAIS"                => $row["CDPAIS"],
            "SGESTADO"              => $row["SGESTADO"],
            "CDMUNICIPIO"           => $row["CDMUNICIPIO"],
            "CDBAIRRO"              => $row["CDBAIRRO"],
            "DSENDECLIE"            => $row["DSENDECLIE"],
            "IDTPENDECLIE"          => $row["IDTPENDECLIE"],
            "NMBAIRCLIE"            => $row["NMBAIRCLIE"],
            "DSCOMPENDCLI"          => $row["DSCOMPENDCLI"],
            "NRCEPCLIE"             => $row["NRCEPCLIE"],
            "NRTELECLIE"            => $row["NRTELECLIE"],
            "NRRAMALCLIE"           => $row["NRRAMALCLIE"],
            "DSEMAILCLIE"           => $row["DSEMAILCLIE"],
            "NRORG"                 => $row["NRORG"],
            "NRORGINCLUSAO"         => $row["NRORG"],
            "CDOPERINCLUSAO"        => $row["CDOPERADOR"],
            "NRENDERECOPARC"        => $row["NRENDERECOPARC"]
        );
        
        $this->clienteFactory->requestForInsertClientAddress($paramsInsertClientAddress);
        
    }
    
    public function callForSelectAddressProspect($row){
        
        $paramsSelectProspectAddress = array(
            
            "CDPROSPECT"            => $row["CDPROSPECT"],
            "NRORG"                 => $row["NRORG"]
            
        );
        
        $returnedAddress = $this->clienteFactory->requestForSelectProspectAddress($paramsSelectProspectAddress);
        return $returnedAddress;
    }
    
    public function callForSetTaskEndDate($row){
        
        $paramsSetTaskEndDate = array(
            
            "NRSEQFILACONTA"        => $row["NRSEQFILACONTA"]
            
        );
        
        $this->clienteFactory->requestForSetTaskEndDate($paramsSetTaskEndDate);
        
    }
    
    public function callForDeactivateProspectTask($taskUpdateParams){
        
        $this->clienteFactory->requestForDeactivateProspectTask($taskUpdateParams);
        
    }
    
    public function replicaInterlocutorProspect($row){
        
        $nrparcnegocioInterlocutor = $this->clienteFactory->getInterlocutorParc($row['NRRELACIONAPARC'], $row['NRORG']);
        if($row['REPLICAENDERECO'] == true){
            $nrenderecoparcInterlocutor = $this->clienteFactory->getEnderecoparcInterlocutor($nrparcnegocioInterlocutor, $row['NRORG']);
            if($nrenderecoparcInterlocutor){
                $paramsUpdate = array(
                    "CDTIPOENDERECO" => $row['IDENDEINPROS'] == 'R' ? 'OUTROS' : 'COMERCIAL' ,
                    "NRORGULTATU" => $row['NRORG'],
                    "CDOPERULTATU" => $row['CODOPERLOGGED'],
                    "CDPAIS" => $row['CDPAIS'],
                    "SGESTADO" => $row['SGESTADO'],
                    "CDMUNICIPIO" => isset($row['CDMUNICIPIO']) ? $row['CDMUNICIPIO'] : '',
                    "CDBAIRRO" => isset($row['CDBAIRRO']) ? $row['CDBAIRRO'] : '',
                    "NMBAIRROENDERECO" => $row['NMBAIRINPROS'],
                    "DSENDERECO" => $row['DSENDEINPROS'],
                    "NRCEPENDERECO" => $row['NRCEPINPROS'],
                    "NRPARCNEGOCIO" => $nrparcnegocioInterlocutor,
                    "NRORG" => $row['NRORG'],
                    "NRENDERECOPARC" => $nrenderecoparcInterlocutor
                );
                $this->clienteFactory->replicaEnderecoparcInterlocutor($paramsUpdate);
            }else{
                $paramsInsert = array(
                    "IDATIVO" => $row['IDATIVO'],
                    "NRPARCNEGOCIO" => $nrparcnegocioInterlocutor,
                    "NRORG" => $row['NRORG'],
                    "NRENDERECOPARC" => $this->newCode->getCodeByTableName("ENDERECOPARC", $row["NRORG"]),
                    "CDTIPOENDERECO" => $row['IDENDEINPROS'] == 'R' ? 'OUTROS' : 'COMERCIAL',
                    "NRORGINCLUSAO" => $row['NRORG'],
                    "CDOPERINCLUSAO" => $row['CODOPERLOGGED'],
                    "CDPAIS" => $row['CDPAIS'],
                    "SGESTADO" => $row['SGESTADO'],
                    "CDMUNICIPIO" => isset($row['CDMUNICIPIO']) ? $row['CDMUNICIPIO'] : '',
                    "CDBAIRRO" => isset($row['CDBAIRRO']) ? $row['CDBAIRRO'] : '',
                    "NMBAIRROENDERECO" => $row['NMBAIRINPROS'],
                    "DSENDERECO" => $row['DSENDEINPROS'],
                    "NRCEPENDERECO" => $row['NRCEPINPROS'],
                    "DSCOMPLEENDERECO" => '',
                    "NRIMOVELENDERECO" => ''
                );
                $this->clienteFactory->insertEnderecoparc($paramsInsert);
            }
        }
    }
    
    public function setIdQualificadoProspect($row){
        
        $paramsSetQualification = array(
            
            "IDQUALIFICADO"         => $row['IDQUALIFICADO'],
            "CDPROSPECT"            => $row["CDPROSPECT"],
            "NRORG"                 => $row["NRORG"]
        );
        
        $this->clienteFactory->setIdQualificadoProspect($paramsSetQualification);
        
    }
    
    public function insertConcorrProspect($row){
        
        $paramsInsertConcorrParc = array(
            
            "NRCONCORRPROSPECT"     => $row["NRCONCORRPROSPECT"],
            "CDPROSPECT"            => $row["CDPROSPECT"],
            "NRCONCORRENTE"         => $row["NRCONCORRENTE"],
            "NRORG"                 => $row["NRORG"],
            "DTINIVIGENCIA"         => $row["DTINIVIGENCIA"],
            "DTFIMVIGENCIA"         => $row["DTFIMVIGENCIA"],
            "CDOPERINCLUSAO"        => $row["CODOPERLOGGED"]
            
        );
        
        $this->clienteFactory->insertConcorrProspect($paramsInsertConcorrParc);
        
    }  
    
    public function updateConcorrProspect($row){
        
        $paramsUpdateConcorrParc = array(
            
            "NRCONCORRPROSPECT"     => $row["NRCONCORRPROSPECT"],
            "NRORG"                 => $row["NRORG"],
            "NRCONCORRENTE"         => $row["NRCONCORRENTE"],
            "DTINIVIGENCIA"         => $row["DTINIVIGENCIA"],
            "DTFIMVIGENCIA"         => $row["DTFIMVIGENCIA"]
            
        );
        
        $this->clienteFactory->updateConcorrProspect($paramsUpdateConcorrParc);
        
    }
    
     public function deleteConcorrProspect($row){
        
        $paramsDeleteConcorrParc = array(
            
            "NRCONCORRPROSPECT"     => $row["NRCONCORRPROSPECT"],
            "NRORG"                 => $row["NRORG"]
            
        );
        
        $this->clienteFactory->deleteConcorrProspect($paramsDeleteConcorrParc);
        
    }
    
    public function validaCNPJCliente($row){
        
        $paramsSelectClient = array(
            
            "CNPJ"                  => $row["CNPJ"],
            "NRORG"                 => $row["NRORG"]
            
        );
        
        $returnedClients = $this->clienteFactory->validaCNPJCliente($paramsSelectClient);
        if(isset($returnedClients[0])){
            return $returnedClients;
        }else{
            return true;
        }
    }
    
    public function createPartnership($row) {
        $nrParcnegocio = $row['NRPARCNEGOCIO'];
        $nrparceiro = $row['NRPARCERIA'];
        $nrOrg = $row['NRORG'];
        $cdoperinclusao = $row['CDOPERINCLUSAO'];
        $cdtipoparceiro = $row["CDTIPOPARCEIRO"]; 
        $params = array(
          "NRPARCERIA"     => $nrparceiro,
          "NRORG"          => $nrOrg,
          "NRPARCNEGOCIO"  => $nrParcnegocio,
          "CDTIPOPARCEIRO" => $cdtipoparceiro,
          "IDATIVO"        => 'S',
          "CDOPERINCLUSAO" => $cdoperinclusao,
          "NRORGINCLUSAO"  => $nrOrg);
        
        $this->clienteFactory->createPartnership($params);
    }
    
    public function setParceiroNegocio($row, $parcCriado) {
        try {
            $params = array (
                "IDATIVO"               => $row["IDATIVO"],
                "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
                "NRORG"                 => $row["NRORG"],
                "NMPRINCIPALPARC"       => $row["NMRAZSOCCLIE"],
                "NMSECUNDARIPARC"       => empty($row["NMFANTCLIE"]) ? $row["NMRAZSOCCLIE"] : $row["NMFANTCLIE"] ,
                "NRINSCRICAOPARC"       => $row["NRINSJURCLIE"],
                "NRORGINCLUSAO"         => $row["NRORG"],
                "CDOPERINCLUSAO"        => $row["CDOPERINCLUSAO"],
                "CDOPERRESPONSAVEL"     => $row["CDOPERRESPONSAVEL"],
                "CDTIPOPARCPRINCIPAL"   => "CLIENTE",
                "CDTIPOINSCRICAO"       => $row["TIPOINSC"],
                "IDPESSOAFISICA"        => $row["ISCPF"],
            );
            if(!$parcCriado) {
                $this->clienteFactory->setParceiroNegocio($params);
            }
            $params['CRM_NRORGTRAB'] = $row['CRM_NRORGTRAB'];
            $params['CDTIPOPARCEIRO'] = $row['CDTIPOPARCEIRO'];
            $params['NRPARCRESP'] = $row['NRPARCRESP'];
            $params['IDSTATUS'] = null;
            $retorno = $this->leadFactory->insertStatusParc($params);
            
            return $retorno;
        } catch(\Exception $e) {
            throw $e;
        };
    }

    public function newContato($row) {
        $params = array (
            "DSREFECONT"    => substr('Referente ao Lead '.$row['NMRAZSOCCLIE'], 0, 59),
            "NRPARCNEGOCIO" => $row['NRPARCNEGOCIO'],
            "NRSEQCONTATO"  => $row['NRSEQCONTATO'],
            "CDOPERCONT"    => $row['CDOPERINCLUSAO'],
            "NRCONTATO"     => $row['NRCONTATO'],
            "CDFILIAL"      => $row['CDFILIAL'],
            "NRORG"         => $row['NRORG'],
            "IDSTATUSCONT"  =>'A',
            "IDTPCONTATO"   =>'P'

        );
        
        $this->clienteFactory->newContato($params);
    }
    
    public function verificaParceiro($params, $tipoParceiro){
        return $this->leadFactory->verificaParceiro($params, $tipoParceiro);
    }
    
    public function updateCliente($row) {
        $cdOperador = $this->environment->getCdOperador();
        $nrorgOper = $this->environment->getNrOrg();
        $nrorg = $this->environment->getNrOrgTrab();
        
        $params = array(
            "IDTPIJURCLIE"      => $row['IDTPIJURCLIE'],
            "NMFANTCLIE"        => $row['NMFANTCLIE'],
            "IDPRIPUBCLIE"      => $row['IDPRIPUBCLIE'],
            "CDMODODIVULG"      => $row['CDMODODIVULG'],
            "CDATIVCLI"         => $row['CDATIVCLI'],
            "CDQUALIF"          => $row['CDQUALIF'],
            "NMRAZSOCCLIE"      => $row['NMRAZSOCCLIE'],
            "NRINSJURCLIE"      => $row['NRINSJURCLIE'],
            "CDSEGMER"          => $row['CDSEGMER'],
            "IDATIVO"           => $row['IDATIVO'],
            "VRFATUCLIE"        => $row['VRFATUCLIE'],
            "NRFUNCCLIE"        => $row['NRFUNCCLIE'],
            "DSHOMEPACLI"       => $row['DSHOMEPACLI'],
            "NRPARCNEGOCIO"     => $row['NRPARCNEGOCIO'],
            "CDCLIENTE"         => $row['CDCLIENTE'],
            "NRINSESTCLIE"      => $row['NRINSESTCLIE'],
            "CDOPERRESPONSAVEL" => $row['CDOPERRESPONSAVEL'],
            
            "CDOPERADOR"        => $cdOperador,
            "NRORGOPER"         => $nrorgOper,
            "NRORG"             => $nrorg
        );
        
        $this->clienteFactory->updateCliente($params);
    }
    
    public function getCdOperador($key, $find = "PARCNEGOCIO") {
        return $this->parceiroFactory->getCdOperador($key, $find);
    }
}
?>